<?php
namespace common\models;

use Yii;
use yii\base\Model;

/**
 * Login form
 */
class LoginForm extends Model
{
    public $username;
    public $password;
    public $type = 1 ;
    public $rememberMe = true;

    private $_user;
    public $verifyCode;

    public $banned;
    public $banned_text;


    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            // username and password are both required
//            [['username', 'password'], 'required'],
            [['username'], 'required',  'message'=>Yii::t('app', 'Забыли указать логин?')],
            [['password'], 'required',  'message'=>Yii::t('app', 'Забыли указать пароль?')],
            // rememberMe must be a boolean value
            ['rememberMe', 'boolean'],
            // password is validated by validatePassword()
            ['password', 'validatePassword'],
            ['type', 'integer'],
            //['verifyCode', 'captcha'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'verifyCode' => 'Я не бот',
            'username' => 'Логин',
            'password' => 'Пароль',
            'rememberMe' => 'Запомнить меня',
        ];
    }

    /**
     * Validates the password.
     * This method serves as the inline validation for password.
     *
     * @param string $attribute the attribute currently being validated
     * @param array $params the additional name-value pairs given in the rule
     */
    public function validatePassword($attribute, $params)
    {
        if (!$this->hasErrors()) {
            $user = $this->getUser();
            if (!$user || !$user->validatePassword($this->password)) {
                $this->addError($attribute, 'Неверные данные логина и пароля.');
            }
        }
    }

    /**
     * Logs in a user using the provided username and password.
     *
     * @return boolean whether the user is logged in successfully
     */
    public function login()
    {
        if ($this->validate()) {
            return Yii::$app->user->login($this->getUser(), $this->rememberMe ? 3600 * 24 * 30 : 0);
        } else {
            return false;
        }
    }

    /**
     * Finds user by [[username]]
     *
     * @return User|null
     */
    protected function getUser()
    {
        if ($this->_user === null) {
            $this->_user = User::findByUsername($this->username, $this->type);
        }

        return $this->_user;
    }

    public function isAdmin()
    {
        if ($this->validate()) {
            if($user = $this->getUser()){
                if($user->role == '1'){
                    return true;
                }
            }
        } else {
            return false;
        }

        return false;
    }

}
